@@ -15,5 +15,5 @@ from .exceptions import NonRequiredParamsMustHaveDefault, InvalidSid
 from .post_ql import post, get_queries
 from .logging import logging
 from .utils.JSDict import JSDict
-from .utils.EventEmitter import EventEmitter
+from .utils.EventEmitter import BasicEventEmitter
 from .utils.switch import Switch
\ No newline at end of file
