@@ -10,12 +10,12 @@ from .utils.switch import Switch
 from os import environ
 from .links import links
 from .logging import logging
-from .utils.EventEmitter import EventEmitter
+from .utils.EventEmitter import BasicEventEmitter
 from time import sleep
 from threading import Thread as _Thread
 from .exceptions import InvalidSid
 
-class Track(EventEmitter):
+class Track(BasicEventEmitter):
     def __init__(self, func: Function[..., Any], ms: int) -> None:
         super().__init__()
         self.f = func
@@ -40,12 +40,12 @@ class Track(EventEmitter):
             self.running = False
             self.t.join()
 
-class Client(EventEmitter):
+class Client(BasicEventEmitter):
     def __init__(self, sid: str) -> None:
         super().__init__()
         logging.log("fetching queries")
         with open("queries.json", "w") as f:
-            req = get(f"https://Queries-Whitelist.bigminiboss.repl.co/{sid}")
+            req = get("https://Queries-Whitelist.bigminiboss.repl.co/")
             f.write(req.text)
         logging.log("finished fetching")
         
@@ -465,6 +465,7 @@ class FollowersManager:
         c = {}
         for u in users:
             user = User(self.c)
+            user.update(u)
             if (options.cache):
                 self.cache[user.username] = user
                 self.c.users.cache[user.username] = user
@@ -557,11 +558,11 @@ class User:
     def update(self, data: Dict[str, Any]):
         """update profile"""
         time_created, presence_status = (None, None)
-        if (getattr(data, "timeCreated", None)):
-            time_created = data.timeCreated
+        if ("timeCreated" in data and data["timeCreated"]):
+            time_created = data["timeCreated"]
             del data["timeCreated"]
-        if (getattr(data, "presenceStatus", None)):
-            presence_status = data.presenceStatus
+        if ("presenceStatus" in data and data["presenceStatus"]):
+            presence_status = data["presenceStatus"]
             del data["presenceStatus"]
         for key in data:
             setattr(self, key, data[key])
